@@ -21,7 +21,7 @@ continuous and irreversible: it's possible to change the current
 time-point to write multiple notes that overlap each other.
 """
 
-__version__ = "1.0.2"
+__version__ = "1.0.3"
 
 import math, random, struct, wave
 
@@ -1466,13 +1466,7 @@ def bytestring(signal, duration, start=0):
 # Tracks #
 #--------#
 
-TRACKS = {
-    "default": {
-        "waveform": silence,
-        "duration": 0,
-        "log": []
-    }
-}
+TRACKS = None
 """
 The various active tracks. Each track name maps to a dictionary
 containing the waveform function for that track and a time value
@@ -1486,9 +1480,9 @@ time, then duration, and then description.
 """
 
 
-ACTIVE_TRACK = "default"
+ACTIVE_TRACK = None
 """
-The currently-active track. By default, this is the track named
+The currently-active track. After a reset, this is the track named
 'default'.
 """
 
@@ -1504,6 +1498,42 @@ def setActiveTrack(name):
     ACTIVE_TRACK = name
 
 
+def resetTracks():
+    """
+    Completely erases and deletes ALL tracks, and uses `resetState` to
+    reset to a clean state.
+    """
+    global TRACKS, ACTIVE_TRACK
+    TRACKS = {
+        "default": {
+            "waveform": silence,
+            "duration": 0,
+            "log": []
+        }
+    }
+    ACTIVE_TRACK = "default"
+    resetState()
+
+
+def resetState():
+    """
+    Resets the current instrument, drum, time, pitch, and volume back to
+    their default values. Does not affect track data (see `resetTracks`).
+    """
+    global CURRENT_INSTRUMENT, CURRENT_DRUM, CURRENT_TIME, CURRENT_PITCH,\
+        CURRENT_VOLUME
+    # Reset things to defaults
+    CURRENT_INSTRUMENT = keyboard
+    CURRENT_DRUM = snare
+    CURRENT_TIME = 0
+    CURRENT_PITCH = A3 # noqa F821
+    CURRENT_VOLUME = 0.6
+
+
+# Reset on import to initialize default track
+resetTracks()
+
+
 def eraseTrack():
     """
     Completely erases the current track, erasing any old contents and
@@ -1548,7 +1578,8 @@ def addRestAt(startAt, duration):
 
     elif not isinstance(startAt, (int, float)) or startAt < 0:
         raise TypeError(
-            "The start time must be a non-negative number or the string 'end'."
+            "The start time must be a non-negative number or the string"
+            " 'end'."
         )
 
     if not isinstance(duration, (int, float)) or duration < 0:
@@ -1904,17 +1935,21 @@ class ZeroLengthTrack:
         return
 
 
-def printTrack():
+def trackDescription():
     """
-    Prints out the log of the current track. When notes overlap, prints
-    their start times, but otherwise just prints each note.
-    TODO: Watch out for gaps?
+    Returns a list of strings describing the notes and/or beats in the
+    current track. Each entry describes one note or beat. When notes
+    overlap, includes their start times, but otherwise just includes an
+    entry for each note with the implication that it starts at the end of
+    the previous note.
     """
     thisTrack = TRACKS[ACTIVE_TRACK]
     skip = 0
     log = thisTrack["log"]
+    result = []
     first = True
     lastSkip = False
+    prevEnd = None
     for i, entry in enumerate(log):
         if skip > 0:
             lastSkip = True
@@ -1924,12 +1959,21 @@ def printTrack():
         start, duration, description = entry
         now = start
         until = start + duration
+
+        # Check for a gap after end of previous entry
+        gap = None
+        if start != prevEnd and prevEnd is not None:
+            gap = start - prevEnd
+        prevEnd = until
+
         offset = 1
         while now < until and i + offset < len(log):
             nextEntry = log[i + offset]
             nextStart, nextDuration, nextDescription = nextEntry
             if nextStart < until: # an overlapping note
-                until = max(until, nextStart + nextDuration)
+                # rests don't alter the "end" time of overlapping stuff
+                if not nextDescription.endswith("rest"):
+                    until = max(until, nextStart + nextDuration)
                 describe.append(nextEntry)
             now = nextStart + nextDuration
             offset += 1
@@ -1937,20 +1981,43 @@ def printTrack():
         if len(describe) == 1:
             if first:
                 first = False
-                print(describe[0][2])
+                result.append(describe[0][2])
             elif lastSkip:
                 lastSkip = False
-                print("at {:.3g}s".format(describe[0][0]), describe[0][2])
+                result.append(
+                    "at {:.3g}s {}".format(
+                        describe[0][0],
+                        describe[0][2]
+                    )
+                )
+            elif gap is not None:
+                result.append("and a {:0.3g}s rest".format(gap))
+                result.append("and " + describe[0][2])
             else:
-                print("and", describe[0][2])
+                result.append("and " + describe[0][2])
         else:
             first = False
             skip = len(describe) - 1
+            if gap is not None:
+                result.append("and a {:0.3g}s rest".format(gap))
             for start, duration, description in describe:
                 if not description.endswith("rest"):
-                    print("at {:.3g}s".format(start), description)
+                    result.append(
+                        "at {:.3g}s {}".format(start, description)
+                    )
                 # overlapping rests are not described
 
+    return result
+
+
+def printTrack():
+    """
+    Prints out the description of the current track (see
+    `trackDescription`).
+    """
+    for entry in trackDescription():
+        print(entry)
+
 
 def prepareTrack():
     """
